@@ -1,7 +1,8 @@
 import argparse
 from .cli import Niscli
+from .tree import Nistree
 
-__version__ = "0.1"
+__version__ = "0.2"
 
 # parse arguments
 argparser = argparse.ArgumentParser(prog="nisanyan_cli")
@@ -11,6 +12,13 @@ argparser.add_argument(
     nargs="*",
     help="<word>",
 )
+argparser.add_argument(
+    "--tree",
+    "-t",
+    action="store_true",
+    default=False,
+    help="show result as etymology tree",
+)
 argparser.add_argument(
     "-v", "--version", action="version", version="%(prog)s v" + __version__
 )
@@ -19,7 +27,10 @@ args = argparser.parse_args()
 
 def cli():
     word = " ".join(args.word)
-    Niscli(word)
+    if args.tree:
+        Nistree(word)
+    else:
+        Niscli(word)
 
 
 if __name__ == "__main__":
